#!/usr/bin/env python3
# -*- coding: utf-8 -*-
import sys
import os
from gettext import gettext as _

sys.path.append(os.path.join(os.path.dirname(__file__), ".."))

from gi import require_version
require_version("Gtk", "3.0")

from gi.repository import Gio
from gi.repository import Gtk
from gi.repository import Gdk
from gi.repository import GLib

from gasimporter.configuration import get_ui_dir
from gasimporter.window import ApplicationWindow
from gasimporter.window import ShortcutsWindow

class Application(Gtk.Application):

    def __init__(self):
        Gtk.Application.__init__(self)

        self.window = None

    def do_startup(self):
        Gtk.Application.do_startup(self)

        #self.build_actions()
        self.build_menu()

    def do_activate(self):
        if self.window:
            return
        self.window = ApplicationWindow(self)
        #.show() vs. .present()
        #http://www.pygtk.org/pygtk2reference/class-gtkwindow.html#method-gtkwindow--present
        self.window.present()

    """
    Create acclerator actions for app-menu
    https://git.gnome.org/browse/gnome-music/tree/gnomemusic/application.py
    """
    def build_actions(self):
        actions = [
            ('preferences', self.preferences, ["<Control>p", "<Control>comma"], _("Open preferences window.")),
            ('help', self.help, ["F3"], _("Open help window.")),
            ('shortcuts', self.shortcuts, ["F2"], _("Open shortcuts window.")),
            ('about', self.about, ["F1"], _("Open about window.")),
            ('quit', self.quit, ["<Control>q"], _("Quit application.")),
        ]

        for action, callback, accelerators, description in actions:
            simpleAction = Gio.SimpleAction.new(action, None)
            simpleAction.connect('activate', callback)
            self.add_action(simpleAction)
            if accelerators:
                self.set_accels_for_action("app.{}".format(action), accelerators)
            if description:
                ShortcutsWindow.add_action("app.{}".format(action), description)

    def build_menu(self):
        menu = Gio.Menu()

        actions = [
            ("preferences", _("Preferences"), self.preferences,["<Control>p", "<Control>comma"], _("Open preferences window.")),
            ("help", _("Help"), self.help, ["F3"], _("Open help window.")),
            ("shortcuts", _("Keyboard Shortcuts"), self.shortcuts, ["F2"], _("Open shortcuts window.")),
            ("about", _("About"), self.about, ["F1"], _("Open about window.")),
            ("quit", _("Quit"), self.quit, ["<Control>q"], _("Quit application.")),
        ]

        for action, title, callback, accelerators, description in actions:
            menu.append(title, "app.{}".format(action))
            simpleAction = Gio.SimpleAction.new(action, None)
            simpleAction.connect('activate', callback)
            self.add_action(simpleAction)
            if accelerators:
                self.set_accels_for_action("app.{}".format(action), accelerators)
            if description:
                ShortcutsWindow.add_action("app.{}".format(action), description)

        self.set_app_menu(menu)





        #builder = Gtk.Builder()
        #builder.add_from_file("{}/{}".format(get_ui_dir(), "app-menu.ui"))
        #menu = builder.get_object("app-menu")

        #self.set_app_menu(menu)

    def preferences(self, action, param):
        self.window.dialog_preferences()

    def help(self, action, param):
        Gtk.show_uri(None, "help:gas-importer", Gdk.CURRENT_TIME)

    def shortcuts(self, action, param):
        self.window.dialog_shortcuts()

    def about(self, action, param):
        self.window.dialog_about()

    def quit(self, action=None, param=None):
        self.window.destroy()

if __name__ == "__main__":
    app = Application()
    exit_status = app.run(sys.argv)
    sys.exit(exit_status)
