#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#import sys
import os
from gettext import gettext as _

from gi import require_version
require_version("Gtk", "3.0")

from gi.repository import Gtk
from gi.repository import Gdk

from gasimporter.configuration import Configuration as Config

class ApplicationWindow(Gtk.ApplicationWindow):
    def __init__(self, app):
        Gtk.ApplicationWindow.__init__(self,
                                       title=Config.APP_NAME,
                                       application=app)

        """
        Build Settings
        """
        self.app = app
        self.set_default_size(320, 480)
        self.set_position(Gtk.WindowPosition.CENTER)

        # Prefer dark theme
        gtksettings = Gtk.Settings.get_default()
        gtksettings.set_property("gtk-application-prefer-dark-theme", True)
        theme = gtksettings.get_property("gtk-theme-name")
        os.environ["GTK_THEME"] = theme + ":dark"

    def build(self):
        self.set_icon_name("gas-importer")

        headerbar = Gtk.HeaderBar()
        headerbar.set_title(Config.APP_NAME)
        headerbar.set_show_close_button(True)
        self.set_titlebar(headerbar)

class AboutWindow(Gtk.AboutDialog):
    def __init__(self, main_window = None):
        Gtk.AboutDialog.__init__(self)

        self.main_window = main_window
        self.connect("response", self.dialog_response)

        """
        Build Settings
        """
        self.set_modal(True)
        self.set_type_hint(Gdk.WindowTypeHint.DIALOG)
        self.set_transient_for(self.main_window)
        self.set_position(Gtk.WindowPosition.CENTER_ON_PARENT)

    def build(self):
        self.set_program_name(Config.APP_NAME)
        self.set_website(Config.APP_URL)
        self.set_version(Config.APP_VERSION)
        self.set_comments(Config.APP_DESCRIPTION)
        self.set_authors(Config.APP_AUTHORS)
        self.set_translator_credits(' '.join(Config.APP_TRANSLATORS))
        self.set_documenters(Config.APP_DOCUMENTERS)
        self.set_license_type(Config.APP_LICENSE)
        self.set_copyright(Config.APP_COMMENTS)
        self.set_icon_name(Config.APP_ICON_NAME)
        self.set_logo_icon_name(Config.APP_LOGO_NAME)

    def dialog_response(self, dialog, response):
        dialog.destroy()

class PrefernecesWindow(Gtk.Window):
    def __init__(self, main_window = None):
        Gtk.Window.__init__(self)

        self.main_window = main_window
        self.connect('key-press-event', self._keypress)

        """
        Build Settings
        """
        self.set_title(_("Preferneces"))
        self.set_default_size(480, 400)
        self.set_modal(True)
        self.set_type_hint(Gdk.WindowTypeHint.DIALOG)
        self.set_transient_for(self.main_window)
        self.set_position(Gtk.WindowPosition.CENTER_ON_PARENT)

    def _keypress(self, widget, event):
        if event.keyval == Gdk.KEY_Escape:
            self.destroy()

    def build(self):
        """
        Build HeaderBar
        """
        headerbar = Gtk.HeaderBar()
        headerbar.set_title(_("Preferneces"))
        headerbar.set_show_close_button(True)
        self.set_titlebar(headerbar)

        """
        Build Content
        """
        notebook = Gtk.Notebook()
        notebook.set_tab_pos(Gtk.PositionType.TOP)

        #pageGeneral = Gtk.Box()
        #pageGeneral.set_border_width(10)
        #pageGeneral.add(options)

        pageGeneral = Gtk.Grid()
        pageGeneral.set_border_width(10)
        option1 = Gtk.Label("Example")
        pageGeneral.add(option1)

        #option1_label = Gtk.Label(_("Option 1"))
        #option1_pref = Gtk.Switch()
        #option1_pref.connect("notify::active", self.on_switch_activated)
        #option1_pref.set_active(True)

        #pageGeneral.add(option1_label)
        #pageGeneral.add(option1_pref)

        notebook.append_page(pageGeneral, Gtk.Label(_("General")))
        self.add(notebook)

    def on_switch_activated(self, switch, gparam):
        if switch.get_active():
            state = "on"
        else:
            state = "off"

        print("Switch was turned", state)

class ShortcutsWindow(Gtk.ShortcutsWindow):
    group_titles = {}
    group_actions = {}
    groups = []

    def __init__(self, main_window = None, app = None):
        Gtk.ShortcutsWindow.__init__(self)

        self.main_window = main_window
        self.app = app

        """
        Build Settings
        """
        self.set_modal(True)
        self.set_type_hint(Gdk.WindowTypeHint.DIALOG)
        self.set_transient_for(self.main_window)
        self.set_position(Gtk.WindowPosition.CENTER_ON_PARENT)

    def build(self):
        """Gathers the accelerators and populates the window."""
        section = Gtk.ShortcutsSection()
        section.show()
        for group_id in ShortcutsWindow.groups:
            group = Gtk.ShortcutsGroup(title=ShortcutsWindow.group_titles[group_id])
            group.show()
            for action, title in ShortcutsWindow.group_actions[group_id]:
                accelerators = " ".join(self.app.get_accels_for_action(action))
                short = Gtk.ShortcutsShortcut(title=title, accelerator=accelerators)
                short.show()
                group.add(short)
            section.add(group)
        # Method below must be called after the section has been populated,
        # otherwise the shortcuts won't show up in search.
        self.add(section)

    @classmethod
    def add_action(cls, action, title, group=None):
        """Adds an action to be displayed.

        Args:
            action (str): The name identifying the action, formatted like
                "prefix.name".
            title (str): The title of the action.
            group (Optional[str]): The group id registered with `register_group`
                to be used instead of the one extracted from `action`.
        """
        action_prefix = group or action.split(".")[0]
        if action_prefix not in cls.group_actions:
            cls.group_actions[action_prefix] = []
        cls.group_actions[action_prefix].append((action, title))

    @classmethod
    def register_group(cls, action_prefix, title):
        """Registers a group of shortcuts to be displayed.

        Args:
            action_prefix (str): The group id.
            title (str): The title of the group.
        """
        if action_prefix not in cls.groups:
            cls.groups.append(action_prefix)
        cls.group_titles[action_prefix] = title
